@@ -23,10 +23,9 @@ import 'dart:math' as Math;
 
 import 'dart:typed_data';
 
-@Native('ArrayBuffer')
-final class NativeByteBuffer extends JavaScriptObject implements ByteBuffer {
-  @JSName('byteLength')
-  external int get lengthInBytes;
+abstract final class NativeByteBuffer extends JavaScriptObject
+    implements ByteBuffer {
+  int get lengthInBytes => JS('', '#.byteLength', this);
 
   Type get runtimeType => ByteBuffer;
 
@@ -97,6 +96,45 @@ final class NativeByteBuffer extends JavaScriptObject implements ByteBuffer {
   }
 }
 
+@Native('ArrayBuffer')
+final class NativeArrayBuffer extends NativeByteBuffer {}
+
+// Interface class that's exposed through `dart:html` to replace the previous
+// `@Native` `SharedArrayBuffer` class that existed there. Marked as `interface`
+// so that classes that implemented it before from `dart:html` still work.
+abstract interface class SharedArrayBuffer extends JavaScriptObject {
+  factory SharedArrayBuffer([int? length]) {
+    if (length != null) {
+      return NativeSharedArrayBuffer._create1(length);
+    }
+    return NativeSharedArrayBuffer._create2();
+  }
+
+  int? get byteLength;
+
+  SharedArrayBuffer slice([int? begin, int? end]);
+}
+
+@Native('SharedArrayBuffer')
+final class NativeSharedArrayBuffer extends NativeByteBuffer
+    implements SharedArrayBuffer {
+  static NativeSharedArrayBuffer _create1(int length) => JS(
+    'returns:NativeSharedArrayBuffer;effects:none;depends:none;new:true',
+    'new SharedArrayBuffer(#)',
+    length,
+  );
+  static NativeSharedArrayBuffer _create2() => JS(
+    'returns:NativeSharedArrayBuffer;effects:none;depends:none;new:true',
+    'new SharedArrayBuffer()',
+  );
+
+  @override
+  int? get byteLength native;
+
+  @override
+  SharedArrayBuffer slice([int? begin, int? end]) native;
+}
+
 /// A fixed-length list of Float32x4 numbers that is viewable as a
 /// [TypedData]. For long lists, this implementation will be considerably more
 /// space- and time-efficient than the default [List] implementation.
